@@ -193,7 +193,7 @@ public class CollectorBean implements EntityBean {
 			new FacilityTreeDB().insertFacilityTree(collectorID, facilityTree);
 			
 			// リポジトリからデバイス情報を取得
-			List deviceList = repository.getDeviceList(facilityID);
+			List<DeviceData> deviceList = repository.getDeviceList(facilityID);
 			
 			// デバイス情報用のDAOを生成
 			DeviceDAO dvdao = new DeviceDAO();
@@ -483,8 +483,8 @@ public class CollectorBean implements EntityBean {
 			} else if (collectorType == CollectorType.MONITOR){
 				// アプリケーションログを出力
 				// 監視IDをログ情報としてログを出力する
-				String[] messages = { "MonitorID : " + label };
-				outputLog(EventCode.WarningRestart, messages);
+//				String[] messages = { "MonitorID : " + label };
+//				outputLog(EventCode.WarningRestart, messages);
 			}
 			
 			// 既に収集中であったもので再実行したものはエラー状態を変更しない
@@ -539,15 +539,15 @@ public class CollectorBean implements EntityBean {
 	 * @ejb.interface-method
 	 *	view-type="both" 
 	 **/
-	public CollectedDataInfo getValue(String facilityId, String itemCode, int deviceIndex){
+	public CollectedDataInfo getValue(String facilityId, String itemCode, int deviceIndex, String deviceName){
 		// 生存期間カウンタをリセット
 		resetLifetimeCounter();
 		
-		CollectedDataInfo data = scopeTree.getValue(facilityId, itemCode, deviceIndex);
+		CollectedDataInfo data = scopeTree.getValue(facilityId, itemCode, deviceIndex, deviceName);
 		
 		// リアルタイム収集で値が取得できなかった場合は前の値を返す
 		if((collectorType == CollectorType.REALTIME) && Double.isNaN(data.getValue())){
-			data = scopeTree.getTempValue(facilityId, itemCode, deviceIndex);
+			data = scopeTree.getTempValue(facilityId, itemCode, deviceIndex, deviceName);
 		}
 		
 		return data;
@@ -565,7 +565,8 @@ public class CollectorBean implements EntityBean {
 				return getValue(
 						facilityId, 
 						items[i].getCollectorItemCode(), 
-						items[i].getDeviceIndex()
+						items[i].getDeviceIndex(),
+						items[i].getDeviceName()
 				);
 			}
 		}
@@ -587,7 +588,8 @@ public class CollectorBean implements EntityBean {
 			dataList[i] = getValue(
 					facilityId, 
 					items[i].getCollectorItemCode(), 
-					items[i].getDeviceIndex()
+					items[i].getDeviceIndex(),
+					items[i].getDeviceName()
 			);
 			
 		}
@@ -601,12 +603,12 @@ public class CollectorBean implements EntityBean {
 	 * @ejb.interface-method
 	 *	view-type="both" 
 	 **/
-	public List getSubScopeValues(String facilityId, String itemCode, int deviceIndex){
+	public List getSubScopeValues(String facilityId, String itemCode, int deviceIndex, String deviceName){
 		ArrayList ret = new ArrayList();		
 		String[] subScopeFids = scopeTree.getSubScopeIDList(facilityId);
 		
 		for(int i=0; i<subScopeFids.length; i++){
-			ret.add(getValue(subScopeFids[i], itemCode, deviceIndex));
+			ret.add(getValue(subScopeFids[i], itemCode, deviceIndex, deviceName));
 		}
 		
 		return ret;
@@ -624,7 +626,8 @@ public class CollectorBean implements EntityBean {
 				return getSubScopeValues(
 						facilityId, 
 						items[i].getCollectorItemCode(), 
-						items[i].getDeviceIndex()
+						items[i].getDeviceIndex(),
+						items[i].getDeviceName()
 				);
 			}
 		}
@@ -842,7 +845,8 @@ public class CollectorBean implements EntityBean {
 						CollectedDataInfo data = getValue(
 								fids[j], 
 								items[i].getCollectorItemCode(), 
-								items[i].getDeviceIndex()
+								items[i].getDeviceIndex(),
+								items[i].getDeviceName()
 						);
 						
 						// DBへ出力
@@ -897,9 +901,10 @@ public class CollectorBean implements EntityBean {
 					String monitorId = monInfoLocal.getMonitorId();
 					String itemCode = monInfoLocal.getItemCode();
 					int deviceIndex = monInfoLocal.getDeviceIndex();
+					String deviceName = monInfoLocal.getDeviceName();
 					
 					// 対象ファシリティ(ノードもしくはスコープ)の閾値判定を実行する
-					CollectedDataInfo data = getValue(this.facilityID, itemCode, deviceIndex);
+					CollectedDataInfo data = getValue(this.facilityID, itemCode, deviceIndex, deviceName);
 					
 					// 閾値判定を実行
 					RunMonitorPerformance2 runMonitor = new RunMonitorPerformance2();
@@ -913,7 +918,7 @@ public class CollectorBean implements EntityBean {
 						String[] nodeFids = scopeTree.getNodeIDList(this.facilityID);
 						
 						for(int j=0; j<nodeFids.length; j++){
-							data = getValue(nodeFids[j], itemCode, deviceIndex);
+							data = getValue(nodeFids[j], itemCode, deviceIndex, deviceName);
 							
 							// 閾値判定を実行
 							runMonitor = new RunMonitorPerformance2();
