@@ -96,8 +96,12 @@ public class DeviceInfoDAOImpl implements DeviceInfoDAO {
 				}
 				
 				//dnからファシリティIDを抽出する
+				//dnは下記の内容となるため、初めに出現する","以前と最後に出現する","以降を削除したあと
+				//"ccFacilityId="を削除する。
+				//dnの内容：
+				//　　"cn=eth0,ccFacilityId=HOST,ou=facility"
 				String dn = ejb.getDn();
-				dn = dn.replaceFirst("[\\s\\w=]*,", "");
+				dn = dn.replaceFirst("[^,]*,", "");
 				dn = dn.replaceFirst(",[\\s\\w=]*", "");
 				dn = dn.replaceFirst(DeviceInfoAttributeConstant.FACILITYID + "=", "");
 				ejb.setFacilityId(dn);
