@@ -33,6 +33,7 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
 import com.clustercontrol.bean.FacilityConstant;
+import com.clustercontrol.bean.SnmpVersionConstant;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.FacilityBean;
 import com.clustercontrol.repository.ejb.entity.FacilityPK;
@@ -215,6 +216,24 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(attrs.get(FacilityAttributeConstant.STATUSWATCH) != null){
 						ejb.setStatusWatch(stringToBoolean((String)attrs.get(FacilityAttributeConstant.STATUSWATCH).get(0)));
 					}
+					//ccSnmpCommunity取得
+					if(attrs.get(FacilityAttributeConstant.SNMPCOMMUNITY) != null){
+						ejb.setSnmpCommunity((String)attrs.get(FacilityAttributeConstant.SNMPCOMMUNITY).get(0));
+					}
+					//ccSnmpPort取得
+					if(attrs.get(FacilityAttributeConstant.SNMPPORT) != null){
+						ejb.setSnmpPort(new Integer((String)attrs.get(FacilityAttributeConstant.SNMPPORT).get(0)));
+					}
+					//ccSnmpVersion取得
+					if(attrs.get(FacilityAttributeConstant.SNMPVERSION) != null){
+						ejb.setSnmpVersion((String)attrs.get(FacilityAttributeConstant.SNMPVERSION).get(0));
+					}
+					
+					//ccFacilitySortValue取得
+					if(attrs.get(FacilityAttributeConstant.SORT_VALUE) != null){
+						ejb.setSnmpVersion((String)attrs.get(FacilityAttributeConstant.SORT_VALUE).get(0));
+					}
+					
 				}
 			} catch (javax.naming.NamingException ex) {
 				if (ex instanceof CommunicationException) {
@@ -578,6 +597,51 @@ public class FacilityDAOImpl implements FacilityDAO {
 					else if(attrs.get(FacilityAttributeConstant.STATUSWATCH) != null && ejb.getStatusWatch() != null){
 						replaceAttrs.put(FacilityAttributeConstant.STATUSWATCH, booleanToString(ejb.getStatusWatch()));
 					}
+					//ccSnmpPort設定
+					if(attrs.get(FacilityAttributeConstant.SNMPPORT) == null && ejb.getSnmpPort() != null){
+						addAttrs.put(FacilityAttributeConstant.SNMPPORT, ejb.getSnmpPort().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPPORT) != null && ejb.getSnmpPort() == null){
+						removeAttrs.put(FacilityAttributeConstant.SNMPPORT, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPPORT) != null && ejb.getSnmpPort() != null){
+						replaceAttrs.put(FacilityAttributeConstant.SNMPPORT, ejb.getSnmpPort().toString());
+					}
+					//ccSnmpCommunity設定
+					if(attrs.get(FacilityAttributeConstant.SNMPCOMMUNITY) == null && ejb.getSnmpCommunity() != null){
+						addAttrs.put(FacilityAttributeConstant.SNMPCOMMUNITY, ejb.getSnmpCommunity());
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPCOMMUNITY) != null && ejb.getSnmpCommunity() == null){
+						removeAttrs.put(FacilityAttributeConstant.SNMPCOMMUNITY, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPCOMMUNITY) != null && ejb.getSnmpCommunity() != null){
+						replaceAttrs.put(FacilityAttributeConstant.SNMPCOMMUNITY, ejb.getSnmpCommunity());
+					}
+					//ccSnmpVersion設定
+					if(attrs.get(FacilityAttributeConstant.SNMPVERSION) == null && ejb.getSnmpVersion() != null){
+						addAttrs.put(FacilityAttributeConstant.SNMPVERSION, ejb.getSnmpVersion());
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPVERSION) != null && ejb.getSnmpVersion() == null){
+						removeAttrs.put(FacilityAttributeConstant.SNMPVERSION, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPVERSION) != null && ejb.getSnmpVersion() != null){
+						replaceAttrs.put(FacilityAttributeConstant.SNMPVERSION, ejb.getSnmpVersion());
+					}
+					
+					//ccSortValue設定
+					if(attrs.get(FacilityAttributeConstant.SORT_VALUE) == null && ejb.getSortValue() != null){
+						
+						addAttrs.put(FacilityAttributeConstant.SORT_VALUE, ejb.getSortValue().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.SORT_VALUE) != null && ejb.getSortValue() == null){
+						
+						removeAttrs.put(FacilityAttributeConstant.SORT_VALUE, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.SORT_VALUE) != null && ejb.getSortValue() != null){
+						
+						replaceAttrs.put(FacilityAttributeConstant.SORT_VALUE, ejb.getSortValue().toString());
+					}
+					
 				}
 				//属性を変更する（追加）
 				ctx.modifyAttributes(
@@ -1753,5 +1817,9 @@ public class FacilityDAOImpl implements FacilityDAO {
 	    ejb.setPingWatchStatus(null);
 	    ejb.setPlatform(null);
 	    ejb.setStatusWatch(null);
+	    ejb.setSnmpPort(null);
+	    ejb.setSnmpCommunity(null);
+	    ejb.setSnmpVersion(null);
+	    ejb.setSortValue(null);
 	}
 }
