@@ -38,7 +38,7 @@ import com.clustercontrol.util.apllog.AplLogger;
 /**
  * FacilityTree(BMP Entity Bean)のDAO実装クラス
  *
- * @version 1.0.0
+ * @version 2.3.0
  * @since 1.0.0
  */
 public class FacilityTreeDAOImpl implements FacilityTreeDAO {
@@ -82,6 +82,9 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				ejb.setFacilityId((String)attrs.get(FacilityTreeAttributeConstant.FACILITYID).get(0));
 				//ccTreeType取得
 				ejb.setTreeType(new Integer((String)attrs.get(FacilityTreeAttributeConstant.TREETYPE).get(0)));
+				ejb.setBuiltIn((new Boolean((String)attrs.get(FacilityTreeAttributeConstant.BUILTIN).get(0))));
+				ejb.setSortValue(new Integer((String)attrs.get(FacilityTreeAttributeConstant.SORT_VALUE).get(0)));
+	
 				m_log.debug("load() : Dn " + pk.getDn() + " FacilityId " + ejb.getFacilityId() + " TreeType " + ejb.getTreeType());
 					
 			} catch ( javax.naming.NamingException ex ) {
@@ -237,6 +240,11 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				attrs.put(OBJECTCLASS, OBJECT_CLASS_FACILITY_TREE);
 				attrs.put(FacilityTreeAttributeConstant.FACILITYID, ejb.getFacilityId());
 				attrs.put(FacilityTreeAttributeConstant.TREETYPE, ejb.getTreeType().toString());
+				attrs.put(FacilityTreeAttributeConstant.SORT_VALUE, ejb.getSortValue().toString());
+				attrs.put(FacilityTreeAttributeConstant.BUILTIN,"FALSE");
+				
+				//↑FALSEは小文字falseはNG
+				
 				
 				// dn文字列作成
 				StringBuffer dn = new StringBuffer();
