@@ -33,6 +33,7 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.accesscontrol.factory.AccessLock;
 import com.clustercontrol.bean.FacilityConstant;
 import com.clustercontrol.bean.Property;
+import com.clustercontrol.bean.SnmpVersionConstant;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.repository.bean.TopicConstant;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoLocal;
@@ -41,6 +42,8 @@ import com.clustercontrol.repository.ejb.entity.FacilityLocal;
 import com.clustercontrol.repository.ejb.entity.FacilityTreeLocal;
 import com.clustercontrol.repository.ejb.entity.FacilityTreeUtil;
 import com.clustercontrol.repository.ejb.entity.FacilityUtil;
+import com.clustercontrol.repository.ejb.entity.FileSystemInfoLocal;
+import com.clustercontrol.repository.ejb.entity.FileSystemInfoUtil;
 import com.clustercontrol.repository.message.UpdateRepositoryInfo;
 import com.clustercontrol.repository.util.SendTopic;
 import com.clustercontrol.util.PropertyUtil;
@@ -55,6 +58,9 @@ import com.clustercontrol.util.apllog.AplLogger;
 public class ModifyFacility {
 	protected static Log m_log = LogFactory.getLog(ModifyFacility.class);
 	
+	//デフォルトのソート順位は100とする。
+	public static int DEFAULT_SORT_ORDER = 100;
+	
 	/**
 	 * スコープ追加
 	 * 
@@ -74,14 +80,16 @@ public class ModifyFacility {
 		ArrayList facilityName = PropertyUtil.getPropertyValue(property, ScopeProperty.FACILITY_NAME);
 		//説明取得
 		ArrayList description = PropertyUtil.getPropertyValue(property, ScopeProperty.DESCRIPTION);
-
+		
+	
 		//Facilityを作成
 		FacilityLocal facility;
 		try {
 			facility = FacilityUtil.getLocalHome().create(
 					(String)facilityId.get(0), 
 					(String)facilityName.get(0), 
-					FacilityConstant.TYPE_SCOPE);
+					FacilityConstant.TYPE_SCOPE
+					);
 					
 			//Facilityに説明を設定
 			facility.setDescription(checkString(description.get(0)));
@@ -97,10 +105,14 @@ public class ModifyFacility {
 		
 		try {
 			//FacilityTreeを作成
+			//FIXME　ソートの順番はとりあえずオンコードで100とする。
 			FacilityTreeLocal facilityTree = FacilityTreeUtil.getLocalHome().create(
 					(String)facilityId.get(0), 
 					FacilityConstant.TYPE_SCOPE, 
-					parentFacilityId);
+					parentFacilityId,
+					new Integer(DEFAULT_SORT_ORDER)
+					);
+			
 			
 		} catch (EJBException e) {
             AplLogger apllog = new AplLogger("REP", "rep");
@@ -197,9 +209,12 @@ public class ModifyFacility {
 		    //親ファシリティIDにFacilityTree(ノード)を作成する
 			for(int i = 0; i < facilityIds.length; i++){
 			    facilityId = facilityIds[i];
+			    //FIXME　ソートの順番はとりあえずオンコードで100+100とする。
+			    //ソート順でスコープよりも後にするため
 			    FacilityTreeLocal facilityTree = 
 			        FacilityTreeUtil.getLocalHome().create(
-			                facilityId, FacilityConstant.TYPE_NODE, parentFacilityId);
+			                facilityId, FacilityConstant.TYPE_NODE, 
+			                parentFacilityId,new Integer(DEFAULT_SORT_ORDER+100));
 			}
 			
 			try {
@@ -325,6 +340,20 @@ public class ModifyFacility {
 //			values = PropertyUtil.getPropertyValue(property, NodeProperty.STATUS_MONITOR);
 //			facility.setStatusWatch((Boolean)values.get(0));
 
+			//ポート番号を取得し、Facilityに設定
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_PORT);
+			facility.setSnmpPort(checkInteger(values.get(0)));
+			//コミュニティ名を取得し、Facilityに設定
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_COMMUNITY);
+			facility.setSnmpCommunity(checkString(values.get(0)));
+			//SNMPバージョンを取得し、Facilityに設定
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_VERSION);
+			facility.setSnmpVersion(checkString(values.get(0)));
+			
+//			FIXME　ソートの順番はとりあえずオンコードで100とする。
+		
+			facility.setSortValue(new Integer(DEFAULT_SORT_ORDER));
+			
 			//nullをセットすることでstore()を呼び出す。
 			facility = null;
 
@@ -359,6 +388,37 @@ public class ModifyFacility {
 				}
 			}
 			
+			//ファイルシステムの配列を取得
+			ArrayList fileSystemList = PropertyUtil.getProperty(property, NodeProperty.FILE_SYSTEM);
+			for(int i = 0; i < fileSystemList.size(); i++){
+			    //ファイルシステムINDEXを取得
+				Property fileSystemProperty= (Property)fileSystemList.get(i);
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
+				Integer cn = checkInteger(values.get(0));
+				
+				if(cn != null){
+					//FileSystemInfoを作成
+					FileSystemInfoLocal fileSystem = FileSystemInfoUtil.getLocalHome().create(
+							cn, 
+							facilityId);
+				
+					if(fileSystem != null){
+					    //マウント位置を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
+						fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
+						//ファイルシステムOIDを取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
+						fileSystem.setSnmpOID(checkString(values.get(0)));
+						//ファイルシステムタイプを取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
+						fileSystem.setFileSystemType(checkString(values.get(0)));
+						//説明を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
+						fileSystem.setDescription(checkString(values.get(0)));
+					}
+				}
+			}
+			
 			try {
 				//Topicに送信
 				SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
@@ -479,6 +539,16 @@ public class ModifyFacility {
 //			values = PropertyUtil.getPropertyValue(property, NodeProperty.STATUS_MONITOR);
 //			facility.setStatusWatch((Boolean)values.get(0));
 			
+			//ポート番号を取得し、Facilityに設定
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_PORT);
+			facility.setSnmpPort(checkInteger(values.get(0)));
+			//コミュニティ名を取得し、Facilityに設定
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_COMMUNITY);
+			facility.setSnmpCommunity(checkString(values.get(0)));
+			//SNMPバージョンを取得し、Facilityに設定
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_VERSION);
+			facility.setSnmpVersion(checkString(values.get(0)));
+			
 		    //Facilityと関連しているデバイスを削除
 			try {
 				//Facilityと関連しているデバイスを取得
@@ -498,8 +568,10 @@ public class ModifyFacility {
 			} catch (RemoveException e) {
 			    m_log.debug("modifyNode() : " + e.getMessage());
 			}
+
+			// ファイルシステムの情報を取得した後で呼び出すため、コメントアウトした。
 			//nullをセットすることでstore()を呼び出す。
-			facility = null;
+			//facility = null;
 			
 			//デバイスの配列を取得
 			ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
@@ -534,6 +606,61 @@ public class ModifyFacility {
 				}
 			}
 			
+			//Facilityと関連しているファイルシステムを削除
+			try {
+				//Facilityと関連しているファイルシステムを取得
+				Collection ct = facility.getFileSystemInfo();
+				
+				//FileSystemInfoを全削除
+				Iterator itr = ct.iterator();
+				FileSystemInfoLocal fileSystem = null;
+				while(itr.hasNext()){
+					fileSystem = (FileSystemInfoLocal)itr.next();
+					fileSystem.remove();
+				}
+			} catch (FinderException e) {
+			    m_log.debug("modifyNode() : " + e.getMessage());
+			} catch (EJBException e) {
+			    m_log.debug("modifyNode() : " + e.getMessage());
+			} catch (RemoveException e) {
+			    m_log.debug("modifyNode() : " + e.getMessage());
+			}
+			//nullをセットすることでstore()を呼び出す。
+			facility = null;
+			
+			//ファイルシステムの配列を取得
+			ArrayList fileSystemList = PropertyUtil.getProperty(property, NodeProperty.FILE_SYSTEM);
+			
+			//ファイルシステムの作成
+			for(int i = 0; i < fileSystemList.size(); i++){
+			    //ファイルシステムINDEXを取得
+				Property fileSystemProperty= (Property)fileSystemList.get(i);
+				values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
+				Integer cn = checkInteger(values.get(0));
+				
+				if(cn != null){					
+					//FileSystemInfoを作成
+					FileSystemInfoLocal fileSystem = FileSystemInfoUtil.getLocalHome().create(
+							cn, 
+							facilityId);
+				
+					if(fileSystem != null){
+					    //マウント位置を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
+						fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
+						//ファイルシステムOIDを取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
+						fileSystem.setSnmpOID(checkString(values.get(0)));
+						//ファイルシステムタイプを取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
+						fileSystem.setFileSystemType(checkString(values.get(0)));
+						//説明を取得し、FileSystemInfoに設定
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
+						fileSystem.setDescription(checkString(values.get(0)));
+					}
+				}
+			}
+			
 			try {
 				//Topicに送信
 				SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
@@ -688,6 +815,19 @@ public class ModifyFacility {
 //					if(values.get(0) != null && values.get(0) instanceof Boolean)
 //					    facility.setStatusWatch((Boolean)values.get(0));
 					
+					//ポート番号を取得し、Facilityに設定
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_PORT);
+					if(checkInteger(values.get(0)) != null)
+						facility.setSnmpPort(checkInteger(values.get(0)));
+					//コミュニティ名を取得し、Facilityに設定
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_COMMUNITY);
+					if(checkString(values.get(0)) != null)
+						facility.setSnmpCommunity(checkString(values.get(0)));
+					//SNMPバージョンを取得し、Facilityに設定
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_VERSION);
+					if(checkString(values.get(0)) != null)
+						facility.setSnmpVersion(checkString(values.get(0)));
+					
 					//デバイスの配列を取得
 					ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
 				    //デバイス名を取得
@@ -745,6 +885,67 @@ public class ModifyFacility {
 							}
 						}
 					}
+					
+					
+					//ファイルシステムの配列を取得
+					ArrayList fileSystemList = PropertyUtil.getProperty(property, NodeProperty.FILE_SYSTEM);
+					
+				    //ファイルシステムINDEXを取得
+					Property fileSystemProperty= (Property)fileSystemList.get(0);
+					values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
+					
+					if(fileSystemList.size() > 0 && checkString(values.get(0)) != null){
+					    //Facilityと関連しているファイルシステムを削除
+						try {
+							//Facilityと関連しているファイルシステムを取得
+							Collection ct = facility.getDeviceInfo();
+							
+							//FileSystemInfoを全削除
+							Iterator itr1 = ct.iterator();
+							FileSystemInfoLocal fileSystem = null;
+							while(itr.hasNext()){
+								fileSystem = (FileSystemInfoLocal)itr1.next();
+								fileSystem.remove();
+							}
+						} catch (FinderException e) {
+						    m_log.debug("modifyAllNode() : " + e.getMessage());
+						} catch (EJBException e) {
+						    m_log.debug("modifyAllNode() : " + e.getMessage());
+						} catch (RemoveException e) {
+						    m_log.debug("modifyAllNode() : " + e.getMessage());
+						}
+					}
+					
+					//ファイルシステムの作成
+					for(int i = 0; i < fileSystemList.size(); i++){
+					    //ファイルシステムINDEXを取得
+						fileSystemProperty= (Property)fileSystemList.get(i);
+						values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_INDEX);
+						Integer cn = checkInteger(values.get(0));
+						
+						if(cn != null){
+							//FileSystemInfoを作成
+							FileSystemInfoLocal fileSystem = FileSystemInfoUtil.getLocalHome().create(
+									cn, 
+									facility.getFacilityId());
+						
+							if(fileSystem != null){
+							    //マウント位置を取得し、FileSystemInfoに設定
+								values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT);
+								fileSystem.setFileSystemMountPoint(checkString(values.get(0)));
+								//ファイルシステムOIDを取得し、FileSystemInfoに設定
+								values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_OID);
+								fileSystem.setSnmpOID(checkString(values.get(0)));
+								//ファイルシステムタイプを取得し、FileSystemInfoに設定
+								values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_TYPE);
+								fileSystem.setFileSystemType(checkString(values.get(0)));
+								//説明を取得し、FileSystemInfoに設定
+								values = PropertyUtil.getPropertyValue(fileSystemProperty, NodeProperty.FILE_SYSTEM_DESCRIPTION);
+								fileSystem.setDescription(checkString(values.get(0)));
+							}
+						}
+					}
+					
 				} catch (CreateException e) {
 				    m_log.debug("modifyAllNode() : " + e.getMessage());
 				}
@@ -919,6 +1120,22 @@ public class ModifyFacility {
                 Boolean attribute = (Boolean)attributes.get(FacilityAttributeConstant.STATUSWATCH);
                 facility.setStatusWatch(attribute);
             }
+            if(attributes.get(FacilityAttributeConstant.SNMPPORT) != null){
+            	//ccSnmpPort取得
+            	Integer attribute = (Integer)attributes.get(FacilityAttributeConstant.SNMPPORT);
+            	facility.setSnmpPort(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.SNMPCOMMUNITY) != null){
+            	//ccSnmpCommunity取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.SNMPCOMMUNITY);
+            	facility.setSnmpCommunity(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.SNMPVERSION) != null){
+            	//ccSnmpVersion取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.SNMPVERSION);
+            	facility.setSnmpVersion(attribute);
+            }
+            
         } catch (FinderException e) {
             m_log.debug("setNodeDetail() : " + e.getMessage());
             throw e;
