@@ -25,6 +25,7 @@ import java.util.Locale;
 import javax.ejb.FinderException;
 import javax.naming.NamingException;
 
+import com.clustercontrol.bean.DeviceTypeConstant;
 import com.clustercontrol.bean.FacilityConstant;
 import com.clustercontrol.bean.FacilityInfo;
 import com.clustercontrol.bean.FacilityTreeItem;
@@ -37,7 +38,10 @@ import com.clustercontrol.repository.ejb.entity.FacilityLocal;
 import com.clustercontrol.repository.ejb.entity.FacilityTreeLocal;
 import com.clustercontrol.repository.ejb.entity.FacilityTreeUtil;
 import com.clustercontrol.repository.ejb.entity.FacilityUtil;
+import com.clustercontrol.repository.ejb.entity.FileSystemInfoLocal;
+import com.clustercontrol.repository.ejb.entity.FileSystemInfoUtil;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
+import com.clustercontrol.repository.factory.NodeFilterProperty;
 import com.clustercontrol.repository.util.ListSorter;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
@@ -187,6 +191,23 @@ public class SelectFacility {
 					//ccPlatform取得
 					map.put(attribute, facility.getStatusWatch());
 				}
+				else if(attribute.compareTo(FacilityAttributeConstant.SORT_VALUE) == 0){
+					//ccSortValue取得
+					map.put(attribute, facility.getSortValue());
+				}
+				// SNMP設定の取得方法を追加
+				else if(attribute.compareTo(FacilityAttributeConstant.SNMPCOMMUNITY) == 0){
+					//ccSnmpCommunity取得
+					map.put(attribute, facility.getSnmpCommunity());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.SNMPPORT) == 0){
+					//ccSnmpPort取得
+					map.put(attribute, facility.getSnmpPort());
+				}
+				else if(attribute.compareTo(FacilityAttributeConstant.SNMPVERSION) == 0){
+					//ccSnmpVersion取得
+					map.put(attribute, facility.getSnmpVersion());
+				}
 			}
 		} catch (FinderException e) {
 			throw e;
@@ -230,13 +251,14 @@ public class SelectFacility {
 	 * @throws FinderException
 	 * @throws NamingException
 	 */
-	public ArrayList getDeviceList(String facilityId) throws FinderException, NamingException {
-		ArrayList list = null;
+	public ArrayList<DeviceData> getDeviceList(String facilityId) throws FinderException, NamingException {
+		ArrayList<DeviceData> list = null;
 		try {
+			//デバイスのデータをリポジトリから取得
 			//FacilityTreeの最上位エントリを取得
 			Collection ct = DeviceInfoUtil.getLocalHome().findByFacilityId(facilityId);
 			
-			list = new ArrayList();
+			list = new ArrayList<DeviceData>();
 			Iterator itr = ct.iterator();
 			while(itr.hasNext()){
 				DeviceInfoLocal d = (DeviceInfoLocal)itr.next();
@@ -249,6 +271,23 @@ public class SelectFacility {
 				
 				list.add(data);
 			}
+			
+			//ファイルシステムのデータをリポジトリから取得
+			//FacilityTreeの最上位エントリを取得
+			ct = FileSystemInfoUtil.getLocalHome().findByFacilityId(facilityId);
+			
+			itr = ct.iterator();
+			while(itr.hasNext()){
+				FileSystemInfoLocal f = (FileSystemInfoLocal)itr.next();
+				DeviceData data = new DeviceData(
+						f.getFacilityId(), 
+						f.getSnmpOID(), 
+						f.getCn(), 		// FileSystemIndex
+						f.getFileSystemMountPoint(), 
+						DeviceTypeConstant.DEVICE_FILESYSTEM);
+				
+				list.add(data);
+			}
 		} catch (FinderException e) {
 			throw e;
 		} catch (NamingException e) {
@@ -591,6 +630,9 @@ public class SelectFacility {
 				info.add(facility.getFacilityId());
 				info.add(facility.getCn());
 				info.add(facility.getDescription());
+				//テーブル定義には３つしかないがソート情報として４番目の項目を
+				//利用する。
+				info.add(ft.getSortValue());
 				list.add(info);
 			}
 		} catch (FinderException e) {
@@ -773,6 +815,12 @@ public class SelectFacility {
 			else{
 				info.setType(FacilityConstant.TYPE_SCOPE);
 			}
+			
+			//ソート順序
+			info.setSortOrder(facilityTree.getSortValue());
+			//組み込みスコープフラグ
+			info.setBuiltInFlg(facilityTree.isBuiltIn());
+			
 			item = new FacilityTreeItem(parent, info);
 		}
 		
@@ -812,6 +860,7 @@ public class SelectFacility {
 			info = new FacilityInfo();
 			info.setFacilityId(facility.getFacilityId());
 			info.setFacilityName(facility.getCn());
+			info.setSortOrder(facilityTree.getSortValue());
 			if(facility.getType() == FacilityConstant.TYPE_SCOPE){
 				info.setType(FacilityConstant.TYPE_SCOPE);
 				item = new FacilityTreeItem(parent, info);
