@@ -97,6 +97,9 @@ public class SnmpTrapCreateDialog extends CommonDialog {
 	/** この設定を有効にする */
 	private Button confirmValid = null;
 	
+	
+	/****/
+	
 	// ----- コンストラクタ ----- //
 	
 	/**
@@ -160,7 +163,9 @@ public class SnmpTrapCreateDialog extends CommonDialog {
 		parent.setLayout(layout);
 		
 		// 監視基本情報
-		monitorBasicComposite = new MonitorBasicScopeComposite(parent, SWT.NONE);
+		//SNMPトラップでは未登録ノードからのトラップを受け付けるようにするので、
+		//第３引数をtrueとする。
+		monitorBasicComposite = new MonitorBasicScopeComposite(parent, SWT.NONE ,true);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -375,7 +380,9 @@ public class SnmpTrapCreateDialog extends CommonDialog {
 			textCommunityName.setText(monitor.getCommunityName());
 		}
 		
+		
 		//OID情報
+		oidListComposite.setCheckMode(monitor.getCheckMode());
 		oidListComposite.setMonitorId(monitor.getMonitorId());
 		oidListComposite.setOidList(monitor.getOidInfos());
 		oidListComposite.update();
@@ -387,7 +394,7 @@ public class SnmpTrapCreateDialog extends CommonDialog {
 		if (monitor.getApplication() != null) {
 			this.notifyInfoComposite.setApplication(monitor.getApplication());
 		}
-
+		
         // ジョブ実行
         m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
         
@@ -432,6 +439,10 @@ public class SnmpTrapCreateDialog extends CommonDialog {
 			return null;
 		}
 		
+		//OIDのチェック方法を設定します。
+		
+		info.setCheckMode(oidListComposite.getCheckMode());
+		
 		//OID情報
 		info.setOidInfos(oidListComposite.getOidList());
 		for(int i = 0; i < info.getOidInfos().size(); i++){
