@@ -37,6 +37,7 @@ import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoPK;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoUtil;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorNumericValueInfoLocal;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorNumericValueInfoUtil;
+import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
@@ -85,11 +86,25 @@ public class SelectMonitorInfo {
 			SnmpTrapInfoLocal info = 
 				SnmpTrapInfoUtil.getLocalHome().findByPrimaryKey(
 						new SnmpTrapInfoPK(monitorId));
+	
+			
+			MonitorInfoPK mipk = new MonitorInfoPK(info.getMonitorId(),
+													MonitorConstant.STRING_SNMPTRAP);
+			
+		    MonitorInfoLocal infoLocal = MonitorInfoUtil.getLocalHome().findByPrimaryKey(mipk);
 			
 			// スコープの取得
 			String facilityPath = repository.getFacilityPath(info.getFacilityId(), null);
 			
+			
 			monitorInfo = new MonitorSnmpTrapInfo();
+			
+			//FIXME
+			/* Monitor情報から何をロードすべきかわからないのでとりあえずのnotNull
+			 * の項目のみを埋めておく*/
+			monitorInfo.setMonitorType(infoLocal.getMonitorType());
+			monitorInfo.setMonitorTypeId(MonitorConstant.STRING_SNMPTRAP);
+			
 			monitorInfo.setMonitorId(info.getMonitorId());
 			monitorInfo.setDescription(info.getDescription());
 			monitorInfo.setFacilityId(info.getFacilityId());
@@ -103,6 +118,7 @@ public class SelectMonitorInfo {
 			monitorInfo.setUpdateDate(info.getUpdateDate());
 			monitorInfo.setRegUser(info.getRegUser());
 			monitorInfo.setUpdateUser(info.getUpdateUser());
+			monitorInfo.setCheckMode(info.getCheckMode());
 			
 			// 監視OID情報取得
 			Collection oids = info.getSnmpTrapOidInfo();
@@ -159,39 +175,39 @@ public class SelectMonitorInfo {
 		// cc_monitor_numeric_value_infoテーブルにその情報を保持している。
 		// 両テーブルから該当監視項目のジョブ連携情報を取得する。
 		
-    	// 監視情報（cc_monitor_info）から、ジョブ実行フラグのみを取得
+		// 監視情報（cc_monitor_info）から、ジョブ実行フラグのみを取得
 		try{
 			MonitorInfoPK mipk = new MonitorInfoPK(monitorId, MonitorConstant.STRING_SNMPTRAP);
 			MonitorInfoLocal infoLocal = MonitorInfoUtil.getLocalHome().findByPrimaryKey(mipk);
 			monitorInfo.setJobRun(infoLocal.getJobRun());
 			
-		    // c_monitor_numeric_value_infoテーブルからジョブ連動の情報取得
+			// c_monitor_numeric_value_infoテーブルからジョブ連動の情報取得
 			Collection ct = MonitorNumericValueInfoUtil.getLocalHome().
 			findByMonitorTypeIdAndMonitorId(MonitorConstant.STRING_SNMPTRAP, monitorId);
-	        Iterator itr = ct.iterator();
+			Iterator itr = ct.iterator();
 			
 			ArrayList<MonitorNumericValueInfo> valueList = new ArrayList<MonitorNumericValueInfo>();
 			
-	        MonitorNumericValueInfoLocal local = null;
-	        while(itr.hasNext()){
-	        	local = (MonitorNumericValueInfoLocal)itr.next();
-	        	MonitorNumericValueInfo value = new MonitorNumericValueInfo(
-	        			local.getMessage(),
-	            		local.getMessageId(),
-	            		local.getMonitorId(),
-	            		local.getMonitorTypeId(),
-	            		local.getPriority(),
-	            		local.getThresholdLowerLimit(),
-	            		local.getThresholdUpperLimit(),
-	            		local.getJobRun(),
-	            		local.getJobId(),
-	            		local.getJobInhibitionFlg(),
-	            		local.getJobFailurePriority());
-	        	valueList.add(value);
-	        }
-	        if(valueList.size() != 0){
-	        	monitorInfo.setJudgementInfo(valueList);
-	        }
+			MonitorNumericValueInfoLocal local = null;
+			while(itr.hasNext()){
+				local = (MonitorNumericValueInfoLocal)itr.next();
+				MonitorNumericValueInfo value = new MonitorNumericValueInfo(
+						local.getMessage(),
+						local.getMessageId(),
+						local.getMonitorId(),
+						local.getMonitorTypeId(),
+						local.getPriority(),
+						local.getThresholdLowerLimit(),
+						local.getThresholdUpperLimit(),
+						local.getJobRun(),
+						local.getJobId(),
+						local.getJobInhibitionFlg(),
+						local.getJobFailurePriority());
+				valueList.add(value);
+			}
+			if(valueList.size() != 0){
+				monitorInfo.setJudgementInfo(valueList);
+			}
 		} catch (FinderException e) {
 			// ジョブ連携の定義がDBに登録されていない場合は、ジョブ連携情報を付加しない
 			// ver2.2.1まではSNMPトラップ監視機能でのジョブ連携が実装されておらず、
@@ -393,6 +409,7 @@ public class SelectMonitorInfo {
 	 */
 	public SnmpTrapMasterInfo getMasterInfo(SnmpTrapMasterPK pk) throws FinderException, NamingException {
 		
+		m_log.debug("getMasterInfo() : start");
 		SnmpTrapMasterInfo info = null;
 		try 
 		{
@@ -421,6 +438,7 @@ public class SelectMonitorInfo {
 			m_log.debug("getMasterInfo():" + e.getMessage());
 			throw e;
 		}
+		m_log.debug("getMasterInfo() : end");
 		return info;
 	}
 	
@@ -457,10 +475,21 @@ public class SelectMonitorInfo {
 				snmpTrapInfo.setFacilityId(facilityId);
 				
 				ArrayList<String> facilityIdList = null;
+				//指定のファシリティIDがノードならば、自分自身をトラップ受信対象の
+				//ファシリティに登録
+				
 				if(repository.isNode(facilityId)){
 					facilityIdList = new ArrayList<String>();
 					facilityIdList.add(facilityId);
 				}
+				//未登録ノードスコープの場合　
+				else if(facilityId.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE) ){
+					
+					//自分自身を登録
+					//see com.clustercontrol.snmptrap.factory.TrapSNMP.snmpReceivedTrap
+					facilityIdList = new ArrayList<String>();
+					facilityIdList.add(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE);
+				}
 				else{
 					facilityIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
 				}
@@ -470,16 +499,33 @@ public class SelectMonitorInfo {
 				
 				ArrayList<SnmpTrapOidInfo> oidList = new ArrayList<SnmpTrapOidInfo>();
 				
-				Iterator itrOid = oids.iterator();
-				while(itrOid.hasNext()){
-					SnmpTrapOidInfoLocal oid = (SnmpTrapOidInfoLocal)itrOid.next();
+				snmpTrapInfo.setCheckMode(info.getCheckMode());
+				
+				if(snmpTrapInfo.getCheckMode() == 1 || snmpTrapInfo.getCheckMode() == 2){
+					//checkMode 1 : すべてのOIDを監視
+					//checkMode 2 : マスター以外のOIDを監視 
 					
-					if(oid.getValidFlg() == ValidConstant.TYPE_VALID){
-						SnmpTrapOidInfo oidInfo = new SnmpTrapOidInfo();
-						oidInfo.setTrapOid(oid.getTrapOid());
-						oidInfo.setGenericId(oid.getGenericId());
-						oidInfo.setSpecificId(oid.getSpecificId());
-						oidList.add(oidInfo);
+					/*SnmpTrapOidInfo oidInfo = new SnmpTrapOidInfo();
+					 oidInfo.setTrapOid("0");
+					 oidInfo.setGenericId(0);
+					 oidInfo.setSpecificId(0);
+					 oidList.add(oidInfo);*/
+					
+					
+				}else{
+					
+					
+					Iterator itrOid = oids.iterator();
+					while(itrOid.hasNext()){
+						SnmpTrapOidInfoLocal oid = (SnmpTrapOidInfoLocal)itrOid.next();
+						
+						if(oid.getValidFlg() == ValidConstant.TYPE_VALID){
+							SnmpTrapOidInfo oidInfo = new SnmpTrapOidInfo();
+							oidInfo.setTrapOid(oid.getTrapOid());
+							oidInfo.setGenericId(oid.getGenericId());
+							oidInfo.setSpecificId(oid.getSpecificId());
+							oidList.add(oidInfo);
+						}
 					}
 				}
 				snmpTrapInfo.setOidList(oidList);
@@ -509,6 +555,7 @@ public class SelectMonitorInfo {
 	@SuppressWarnings("unchecked")
 	public HashMap<String, SnmpTrapFacilityInfo> getSnmpTrapFacilityMap() throws CreateException, FinderException, NamingException {
 		
+		m_log.debug("getSnmpTrapFacilityMap() :start");
 		// SNMPTRAP監視一覧を取得
 		HashMap<String, SnmpTrapFacilityInfo> map = new HashMap<String, SnmpTrapFacilityInfo>();
 		try 
@@ -521,7 +568,12 @@ public class SelectMonitorInfo {
 			Iterator itr = ct.iterator();
 			while(itr.hasNext())
 			{
+				
 				SnmpTrapInfoLocal info = (SnmpTrapInfoLocal)itr.next();
+				
+				
+				
+				
 				// 監視OID情報取得
 				Collection oids = info.getSnmpTrapOidInfo();
 				
@@ -529,41 +581,76 @@ public class SelectMonitorInfo {
 				
 				if(info.getValidFlg() == ValidConstant.TYPE_VALID){
 					
+					//有効のチェックがされている場合にデータをつくる。
+					
+					//監視ID
 					String monitorId = info.getMonitorId();
 					snmpTrapInfo.setMonitorId(monitorId);
 					
+					//設定ダイアログのfacilityID(スコープ)
 					String facilityId = info.getFacilityId();
 					snmpTrapInfo.setFacilityId(facilityId);
 					
+					
+					//配下のノードたちのfacilityIDを格納（ダイアログ設定でノードの場合には自分自身）
 					ArrayList<String> facilityIdList = null;
 					if(repository.isNode(facilityId)){
 						facilityIdList = new ArrayList();
 						facilityIdList.add(facilityId);
+					}else if(facilityId.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)){
+						
+						//未登録ノードスコープの時は自分を検索対象ファシリティにします。
+//						see com.clustercontrol.snmptrap.factory.TrapSNMP.snmpReceivedTrap
+						facilityIdList = new ArrayList<String>();
+						facilityIdList.add(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE);	
 					}
 					else{
 						facilityIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
 					}
 					snmpTrapInfo.setFacilityIdList(facilityIdList);
 					
+					
 					snmpTrapInfo.setCommunityName(info.getCommunityName());
 					
+					snmpTrapInfo.setCheckMode(info.getCheckMode());
+					
+					//OIDのリストを作成する。
 					ArrayList<SnmpTrapOidInfo> oidList = new ArrayList<SnmpTrapOidInfo>();
 					
-					Iterator itrOid = oids.iterator();
-					while(itrOid.hasNext()){
-						SnmpTrapOidInfoLocal oid = (SnmpTrapOidInfoLocal)itrOid.next();
-						
-						if(oid.getValidFlg() == ValidConstant.TYPE_VALID){
-							SnmpTrapOidInfo oidInfo = new SnmpTrapOidInfo();
-							oidInfo.setTrapOid(oid.getTrapOid());
-							oidInfo.setGenericId(oid.getGenericId());
-							oidInfo.setSpecificId(oid.getSpecificId());
-							oidList.add(oidInfo);
-						}
-					}
-					snmpTrapInfo.setOidList(oidList);
+					m_log.debug("getSnmpTrapFacilityMap() :CheckMode() " + snmpTrapInfo.getCheckMode());
 					
-					map.put(monitorId, snmpTrapInfo);
+					if(snmpTrapInfo.getCheckMode() == 1 || snmpTrapInfo.getCheckMode() == 2){
+						//checkMode 1 : すべてのOIDを監視
+						//checkMode 2 : マスター以外のOIDを監視 
+						
+						/*SnmpTrapOidInfo oidInfo = new SnmpTrapOidInfo();
+						 oidInfo.setTrapOid("0");
+						 oidInfo.setGenericId(0);
+						 oidInfo.setSpecificId(0);
+						 oidList.add(oidInfo);*/
+						
+						
+					}else{
+						
+						//指定OIDのみを監視する場合。
+						
+						Iterator itrOid = oids.iterator();
+						while(itrOid.hasNext()){
+							SnmpTrapOidInfoLocal oid = (SnmpTrapOidInfoLocal)itrOid.next();
+							
+							if(oid.getValidFlg() == ValidConstant.TYPE_VALID){
+								//ダイアログのトラップそれぞれにも"変更"で
+								//有効・無効が設定できるらしい。
+								SnmpTrapOidInfo oidInfo = new SnmpTrapOidInfo();
+								oidInfo.setTrapOid(oid.getTrapOid());
+								oidInfo.setGenericId(oid.getGenericId());
+								oidInfo.setSpecificId(oid.getSpecificId());
+								oidList.add(oidInfo);
+							}
+						}
+						snmpTrapInfo.setOidList(oidList);
+					}
+						map.put(monitorId, snmpTrapInfo);
 				}
 			}
 		} catch (CreateException e) {
@@ -576,6 +663,62 @@ public class SelectMonitorInfo {
 			m_log.debug("getSnmpTrapMap():" + e.getMessage());
 			throw e;
 		}
+		m_log.debug("getSnmpTrapFacilityMap() :end");
 		return map;
 	}
+
+	public SnmpTrapMasterInfo findMasterInfo(String trapOid, int genericId, int specificId) {
+	
+		m_log.debug("findMasterInfo() : start");
+		
+		SnmpTrapMasterInfo info = new SnmpTrapMasterInfo();
+		
+		try {
+			
+			Collection masters = SnmpTrapMasterUtil.getLocalHome().findByOid(trapOid,genericId,specificId );
+		
+			
+			if(masters.size() == 1){
+			
+				//マスター情報すべての場合には、
+				//pkからSnmpTrapMaserInfoを作るメソッドを予呼ぶ。				
+
+					SnmpTrapMasterLocal master=(SnmpTrapMasterLocal)masters.iterator().next();
+								
+					info.setMib(master.getMib());
+					info.setTrapOid(master.getTrapOid());
+					info.setGenericId(master.getGenericId().intValue());
+					info.setSpecificId(master.getSpecificId().intValue());
+					info.setUei(master.getUei());
+					info.setLogmsg(master.getLogmsg());
+					info.setDescr(master.getDescr());
+					info.setPriority(master.getPriority());
+	
+					return info;
+				
+			}else if(masters.size() == 0 ){
+				
+				//検索の結果が０というので、未登録MIBを判定します。
+				
+				
+				//判定条件はMIBがnull
+				
+				info.setTrapOid(trapOid);
+				info.setMib(null);
+				return info;
+			}
+			
+		} catch (FinderException e) {
+			m_log.error("findMasterInfo():" + e.getMessage());
+			e.printStackTrace();
+			
+		} catch (NamingException e) {
+			
+			m_log.error("findMasterInfo():" + e.getMessage());
+			e.printStackTrace();
+		}
+		
+		return null;
+		
+	}
 }
