@@ -33,10 +33,12 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.commons.util.SendQueue;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
+import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 import com.clustercontrol.repository.message.UpdateRepositoryInfo;
+import com.clustercontrol.snmptrap.bean.MonitorSnmpTrapInfo;
 import com.clustercontrol.snmptrap.bean.QueueConstant;
 import com.clustercontrol.snmptrap.bean.SnmpTrapFacilityInfo;
 import com.clustercontrol.snmptrap.bean.SnmpTrapOidInfo;
@@ -111,9 +113,11 @@ public class TrapSnmpManager {
 			m_repository = RepositoryControllerUtil.getLocalHome().create();
 			
 			// キャッシュ取得
+			
 			updateCache();
 			
-			// 受信トピック生成
+			// 受信トピック生成(SNMPTrap監視設定、リポジトリ情報の変更を
+			// お知らせする用
 			m_receiveRepositoryTopic = new ReceiveRepositoryTopic(this);
 			m_receiveSnmpTrapTopic = new ReceiveSnmpTrapTopic(this);
 			
@@ -147,6 +151,7 @@ public class TrapSnmpManager {
 	
 	/**
 	 * SNMPTRAP監視対象かチェックし、対象の場合は通知
+	 *  snmpReceivedTrap（トラップ到着）から呼ばれるメソッド
 	 * 
 	 * @param trapDate SNMPトラップ受信日時
 	 * @param communityName コミュニティ名
@@ -164,12 +169,16 @@ public class TrapSnmpManager {
 			int genericId, 
 			int specificId, 
 			String[] varBind,
-			ArrayList<String> facilityIdList) {
+			ArrayList<String> facilityIdList,
+			String agentAdder) {
+		
+		m_log.debug("find() : start" + trapOid);
 		
 		if(m_snmpTrapInfoMap == null)
 			return true;
 		
-		Set set = m_snmpTrapInfoMap.keySet();
+		Set set = m_snmpTrapInfoMap.keySet(); //setはMonitorIdの集合
+		
 		for (Iterator iter = set.iterator(); iter.hasNext();) {
 			String monitorId = (String) iter.next();
 			
@@ -178,7 +187,10 @@ public class TrapSnmpManager {
 				continue;
 			
 			// コミュニティ名が同一か
+			
 			String communityNameCache = info.getCommunityName();
+			/*m_log.error("find() : communityNameCache " + communityNameCache);
+			 m_log.error("find() : communityName " + communityName);*/
 			if(communityNameCache.equals(communityName)){
 				
 				// ファシリティIDが含まれているか
@@ -186,43 +198,84 @@ public class TrapSnmpManager {
 				
 				ArrayList<String> targetFacilityIdList = new ArrayList<String>(facilityIdList);
 				targetFacilityIdList.retainAll(facilityIdListCache);
-				
+				//m_log.error("monitorId : " + info.getMonitorId());
+				//m_log.error("find() : targetFacilityIdList.size() " + targetFacilityIdList.size());
 				if(targetFacilityIdList.size() > 0){
 					
-					// 一致するOID情報が存在するか
-					ArrayList<SnmpTrapOidInfo> oidListCache = info.getOidList();
-					for (int index = 0; index < oidListCache.size(); index++) {
-						SnmpTrapOidInfo oidInfo = oidListCache.get(index);
+					
+					if((info.getCheckMode() == MonitorSnmpTrapInfo.ALL_OID) ||
+							(info.getCheckMode() == MonitorSnmpTrapInfo.UNREGISTERED_OID)){
 						
-						// OIDが同一か
-						if(trapOid.equals(oidInfo.getTrapOid())){
-							// Generic IDが同一か
-							if(genericId == oidInfo.getGenericId()){
-								// Specific IDが同一か
-								if(specificId == oidInfo.getSpecificId()){
-									
-									for (int j = 0; j < targetFacilityIdList.size(); j++) {
-										String facilityId = targetFacilityIdList.get(j);
-										SnmpTrapMessageInfo message = new SnmpTrapMessageInfo(
-												monitorId,
-												facilityId,
-												trapDate,
-												trapOid,
-												genericId,
-												specificId,
-												varBind
-										);
+						
+						//m_log.trace(" MonitorSnmpTrapInfo.ALL_OID or MonitorSnmpTrapInfo.UNREGISTERED_OID ");
+						//m_log.trace("info.getCheckMode() :" + info.getCheckMode() );
+						//すべてのを監視する場合と未登録OIDを監視する場合には、
+						//OIDのチェックを行わず、Queueに投げ込む。
+						for (int j = 0; j < targetFacilityIdList.size(); j++) {
+							String facilityId = targetFacilityIdList.get(j);
+							SnmpTrapMessageInfo message = new SnmpTrapMessageInfo(
+									monitorId,
+									facilityId,
+									trapDate,
+									trapOid,
+									genericId,
+									specificId,
+									varBind,
+									agentAdder
+							);
+							
+							// SNMPトラップ情報通知
+							try {
+								m_sendQueue.put(message);
+							} catch (JMSException e) {
+								m_log.error("find() : 通知失敗。" + e.getMessage());
+								return false;
+							}
+						}
+					}else{
+						// 一致するOID情報が存在するか
+						ArrayList<SnmpTrapOidInfo> oidListCache = info.getOidList();
+						for (int index = 0; index < oidListCache.size(); index++) {
+							SnmpTrapOidInfo oidInfo = oidListCache.get(index);
+							
+							
+							//
+							
+							// OIDが同一か
+							if(trapOid.equals(oidInfo.getTrapOid())){
+								// Generic IDが同一か
+								if(genericId == oidInfo.getGenericId()){
+									// Specific IDが同一か
+									if(specificId == oidInfo.getSpecificId()){
 										
-										// SNMPトラップ情報通知
-										try {
-											m_sendQueue.put(message);
-										} catch (JMSException e) {
-											m_log.error("find() : 通知失敗。" + e.getMessage());
-											return false;
+										//m_log.error("oidInfo : " + oidInfo.getGenericId() + " " + oidInfo.getTrapOid() + " " + oidInfo.getSpecificId());
+										
+										
+										for (int j = 0; j < targetFacilityIdList.size(); j++) {
+											String facilityId = targetFacilityIdList.get(j);
+											SnmpTrapMessageInfo message = new SnmpTrapMessageInfo(
+													monitorId,
+													facilityId,
+													trapDate,
+													trapOid,
+													genericId,
+													specificId,
+													varBind,
+													agentAdder
+											);
+											
+											// SNMPトラップ情報通知
+											try {
+												m_sendQueue.put(message);
+											} catch (JMSException e) {
+												m_log.error("find() : 通知失敗。" + e.getMessage());
+												return false;
+											}
 										}
 									}
 								}
 							}
+							
 						}
 					}
 				}
@@ -238,6 +291,7 @@ public class TrapSnmpManager {
 	 */
 	public void updateCache() {
 		
+		
 		// SNMPTRAP監視情報更新
 		updateSnmpTrapInfo();
 		
@@ -353,6 +407,12 @@ public class TrapSnmpManager {
 						if(repository.isNode(facilityId)){
 							tmpFacilityIdList = new ArrayList<String>();
 							tmpFacilityIdList.add(facilityId);
+						}else if(facilityId.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)){
+							
+							//未登録ノードスコープの時は自分を検索対象ファシリティにします。
+//							see com.clustercontrol.snmptrap.factory.TrapSNMP.snmpReceivedTrap
+							tmpFacilityIdList = new ArrayList<String>();
+							tmpFacilityIdList.add(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE);	
 						}
 						else{
 							tmpFacilityIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
@@ -391,12 +451,30 @@ public class TrapSnmpManager {
 	@SuppressWarnings("unchecked")
 	public boolean updateSnmpTrapInfo() {
 		
+		m_log.debug("updateSnmpTrapInfo(): start");
+		
 		m_snmpTrapInfoMap = new ConcurrentHashMap<String, SnmpTrapFacilityInfo>();
 		
 		try{
+			//セッションビーンに経由で、SNMPTRAP監視マップを取得します。
+			//SNMPTRAP監視マップってなんだ？
 			MonitorSnmpTrapRunManagementLocal management = MonitorSnmpTrapRunManagementUtil.getLocalHome().create();
 			m_snmpTrapInfoMap = management.getSnmpTrapMap();
 			
+			/* デバッグ用コード*/
+			/*Set set = m_snmpTrapInfoMap.keySet(); //setはMonitorIdの集合
+			 m_log.debug("updateSnmpTrapInfo(): set.size() " + set.size());
+			 
+			 
+			 for (Iterator iter = set.iterator(); iter.hasNext();) {
+			 String monitorId = (String) iter.next();
+			 
+			 SnmpTrapFacilityInfo info = m_snmpTrapInfoMap.get(monitorId);
+			 
+			 m_log.error("updateSnmpTrapInfo() : monitorId" + monitorId);
+			 m_log.error("updateSnmpTrapInfo() : chekcMode" + info.getCheckMode());
+			 }*/
+			
 			return true;
 			
 		} catch (CreateException e) {
@@ -421,12 +499,15 @@ public class TrapSnmpManager {
 		// SNMPTRAP監視に設定されている全ファシリティID取得
 		if(m_snmpTrapInfoMap != null){
 			
+			//監視設定の集合からkey(MonitorID)をとりだす。
 			Set set = m_snmpTrapInfoMap.keySet();
 			for (Iterator iter = set.iterator(); iter.hasNext();) {
 				String monitorId = (String) iter.next();
 				
+				//ここのSNMP Trap 監視情報（１設定）をとりだす。
 				SnmpTrapFacilityInfo info = m_snmpTrapInfoMap.get(monitorId);
 				if(info != null){
+					//監視設定からFacilityIDのリストを取り出しfacilityIdListに追加する。			
 					ArrayList<String> tmpFacilityIdList = info.getFacilityIdList();
 					if(tmpFacilityIdList != null && tmpFacilityIdList.size() > 0){
 						facilityIdList.addAll(tmpFacilityIdList);
@@ -435,7 +516,7 @@ public class TrapSnmpManager {
 			}
 		}
 		
-		// リポジトリ情報更新
+		// 全部の監視設定から抽出したfacilityIDのリストで別のメソッド↓を呼ぶ
 		boolean result = updateRepositoryInfo(facilityIdList);
 		return result;
 	}
@@ -447,6 +528,7 @@ public class TrapSnmpManager {
 	 */
 	public boolean updateRepositoryInfo(ArrayList<String> facilityIdList) {
 		
+		//IPAddressがキー、facilityIDのセットが入っているArrayListがObjectのHashmap
 		m_ipAddressMap = new ConcurrentHashMap<String, ArrayList<String>>();
 		m_hostNameMap = new ConcurrentHashMap<String, ArrayList<String>>();
 		
@@ -454,33 +536,47 @@ public class TrapSnmpManager {
 			// ノードの属性取得
 			if(facilityIdList != null && facilityIdList.size() > 0){
 				
+				//facilityIdのリストを元に、リポジトリに IPNETWORKNUMBER IPNETWORKNUMBERV6 NODENAME
+				//を問い合わせに行く。結果はHashMap<facilityID , 3つ入ったオブジェクト>
 				HashMap facilityAttrMap = m_repository.getNodeDetail(facilityIdList, m_attributeList);
 				
+				//帰ってきたオブジェクトからHapMapのキーであるfacilityIDのsetを取得
 				Set keySet = facilityAttrMap.keySet();
 				for (Iterator iter = keySet.iterator(); iter.hasNext();) {
 					String facilityId = (String) iter.next();
 					
+					//facilityIDをキーにして属性のHaahMapを取得する。
 					HashMap map = (HashMap)facilityAttrMap.get(facilityId);
+					//属性のHashMapから各属性を読み出す。
 					String ipNetworkNumber = (String)map.get(FacilityAttributeConstant.IPNETWORKNUMBER);
 					String hostName = (String)facilityAttrMap.get(FacilityAttributeConstant.NODENAME);
 					
 					if(ipNetworkNumber != null && !"".equals(ipNetworkNumber)){
+						//IPアドレスをキーにしてそのオブジェクトを取り出す。
 						ArrayList<String> tmpFacilityIdList = m_ipAddressMap.get(ipNetworkNumber);
 						if(tmpFacilityIdList == null){
+							//未定義の場合には初期化
 							tmpFacilityIdList = new ArrayList<String>();
 						}
 						if(!tmpFacilityIdList.contains(facilityId)){
+							//まだそのfacilityIDが入っていなければ追加
 							tmpFacilityIdList.add(facilityId);
 						}
+						//IpアドレスマップにipアドレスのキーとfacilityIDのArrayListで
+						//putする。
 						m_ipAddressMap.put(ipNetworkNumber, tmpFacilityIdList);
 					}
 					
 					if(hostName != null && !"".equals(hostName)){
+						//ホスト名をキーにしてfacilityIDのリストを取得
 						ArrayList<String> tmpFacilityIdList = m_hostNameMap.get(hostName);
+						
 						if(tmpFacilityIdList == null){
+							//未定義の場合には初期化
 							tmpFacilityIdList = new ArrayList<String>();
 						}
 						if(!tmpFacilityIdList.contains(facilityId)){
+							//まだそのfacilityIDが入っていなければ追加
 							tmpFacilityIdList.add(facilityId);
 						}
 						tmpFacilityIdList.add(facilityId);
