@@ -336,7 +336,7 @@ public class LogCreateDialog extends CommonDialog {
         button.setText(Messages.getString("refer"));
         button.addSelectionListener(new SelectionAdapter() {
             public void widgetSelected(SelectionEvent e) {
-                ScopeTreeDialog dialog = new ScopeTreeDialog(getParentShell());
+                ScopeTreeDialog dialog = new ScopeTreeDialog(getParentShell(),false,true);
                 if (dialog.open() == IDialogConstants.OK_ID) {
                     FacilityTreeItem item = dialog.getSelectItem();
                     FacilityInfo info = item.getData();
