@@ -47,6 +47,7 @@ import com.clustercontrol.calendar.ejb.session.CalendarControllerHome;
 import com.clustercontrol.monitor.bean.QueueConstant;
 import com.clustercontrol.monitor.message.LogOutputNotifyInfo;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
+import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.ejb.session.RepositoryController;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerHome;
@@ -84,6 +85,9 @@ public class EJBContoroler {
 	/** プロパティのキー：メッセージファイルの拡張子。 */
 	private final static String MSG_FILE_SUFFIX = "msg.file.msg.syffix";
 	
+	/** ディレクトリ下に作成するファイルの上限 */
+	private final static String MAX_FILE_COUNT = "msg.max.file.count";
+	
 	/** コネクション。 */
 	private QueueConnection m_con;
 	
@@ -163,8 +167,14 @@ public class EJBContoroler {
 		//ファイル入出力ユーティリティ
 		String filePath = m_props.getProperty(MSG_FILE_PATH, ".");
 		String msgSuffix = m_props.getProperty(MSG_FILE_SUFFIX, ".msg");
+		int maxFileCount;
+		try {
+			maxFileCount = Integer.parseInt(props.getProperty(MAX_FILE_COUNT, ".txt"));
+		} catch (Exception e){
+			maxFileCount = -1;
+		}
 		
-		m_fileUtil = new FileUtil(filePath, msgSuffix);
+		m_fileUtil = new FileUtil(filePath, msgSuffix, maxFileCount);
 		
 		
 		//サーバー接続処理
@@ -180,7 +190,7 @@ public class EJBContoroler {
 				m_cacheInterval);
 		
 	}
-
+	
 	/**
 	 * メッセージ送信の初期処理を行います。
 	 * <p>
@@ -218,7 +228,7 @@ public class EJBContoroler {
 			
 			//コネクションが切れた際のハンドリング
 			m_con.setExceptionListener(new JMSExceptionListener());
-
+			
 			//セッション生成
 			m_session = m_con.createQueueSession(false,
 					Session.AUTO_ACKNOWLEDGE);
@@ -285,47 +295,64 @@ public class EJBContoroler {
 			//
 			// EJB初期処理
 			//
-			log.debug("EJBメソッド初期化");
+			log.debug("EJBインターフェース初期化");
 			logFilter = m_logFilterHome.create();
 			repositoryController = m_repositoryHome.create();
 			
 			
-			//フィルタ情報取得
+			//フィルタ情報取得（ダイアログで見えるものリストと同じ？）
 			ArrayList filterList = logFilter.getFilterInfoList();
 			
+			//実際に実行するときのフィルタ情報
 			filterRepList = new ArrayList<LogFilterRepositoryInfo>();
 			
-			// syslog-ng監視条件とリポジトリ情報でフィルタ条件情報を作成
+			// syslog-ng監視条件には対象のfacilityIDしか含まないので、
+			//　リポジトリにアクセスを行い、フィルタ条件情報（ホスト名）を作成
 			for (Iterator iter = filterList.iterator(); iter.hasNext();) {
+				
+				//１つ１つのフィルタ条件を有効フラグを確認して、
+				//実行用のフィルタ条件としていく
 				LogFilterInfo filterInfo = (LogFilterInfo) iter.next();
 				if (filterInfo.isValidFlg()) {
+					
 					LogFilterRepositoryInfo filterRepInfo = 
 						new LogFilterRepositoryInfo(filterInfo);
 					
 					String facilityID = filterInfo.getFacilityId();
 					log.debug("getList For:" + facilityID);
 					
-					//配下の一覧
-					ArrayList facilityList = repositoryController
-					.getNodeFacilityIdList(facilityID,
-							RepositoryControllerBean.ALL);
 					
-					//配下にノードがないということはノードの可能性があるので指定されたIDをセット
-					if (facilityList.size() == 0) {
-						facilityList.add(facilityID);
+					//未登録ノード対応
+					//登録ノードのホスト名のリストをここでは入れておき、
+					//containsのメソッドで除外する
+					
+					if(facilityID.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)){
+						
+						facilityID=FacilityTreeAttributeConstant.REGISTEREFD_SCOPE;
+						
 					}
-					
-					//ノード名取得
-					ArrayList<String> attributeList = new ArrayList<String>();
-					attributeList.add(FacilityAttributeConstant.NODENAME);
-					attributeList.add(FacilityAttributeConstant.CN);
-					
-					HashMap facilityAttrMap = repositoryController
-					.getNodeDetail(facilityList, attributeList);
-					
-					filterRepInfo.setMap(facilityAttrMap);
-					
-					filterRepList.add(filterRepInfo);
+						
+						//配下の一覧
+						ArrayList facilityList = repositoryController
+						.getNodeFacilityIdList(facilityID,
+								RepositoryControllerBean.ALL);
+						
+						//配下にノードがないということはノードの可能性があるので指定されたIDをセット
+						if (facilityList.size() == 0) {
+							facilityList.add(facilityID);
+						}
+						
+						//ノード名取得
+						ArrayList<String> attributeList = new ArrayList<String>();
+						attributeList.add(FacilityAttributeConstant.NODENAME);
+						attributeList.add(FacilityAttributeConstant.CN);
+						
+						HashMap facilityAttrMap = repositoryController
+						.getNodeDetail(facilityList, attributeList);
+						
+						filterRepInfo.setMap(facilityAttrMap);
+						
+						filterRepList.add(filterRepInfo);
 					
 				}
 				
